
  <!-- Account password policy -->
  <script id="services.iam.password_policy.details.template" type="text/x-handlebars-template">
  <div class="list-group" id="services.iam.password_policy.details">
  <div class="list-group" id="services.iam.password_policy.view">
    <div class="list-group-item active">
      <h4 class="list-group-item-heading">Password policy</h4>
    </div>
    <div class="list-group-item">
      <div class="list-group-item-text item-margin">Minimum password length: <span id="iam.password_policy.MinimumPasswordLength">{{items.MinimumPasswordLength}}</span></div>
      <div class="list-group-item-text item-margin">Require at least one uppercase letter: <span id="iam.password_policy.RequireUppercaseCharacters">{{items.RequireUppercaseCharacters}}</span></div>
      <div class="list-group-item-text item-margin">Require at least one lowercase letter: <span id="iam.password_policy.RequireLowercaseCharacters">{{items.RequireLowercaseCharacters}}</span></div>
      <div class="list-group-item-text item-margin">Require at least one number: <span id="iam.password_policy.RequireNumbers">{{items.RequireNumbers}}</span></div>
      <div class="list-group-item-text item-margin">Require at least one non-alphanumeric character: <span id="iam.password_policy.RequireSymbols">{{items.RequireSymbols}}</span></div>
      <div class="list-group-item-text item-margin">Enable password expiration: <span id="iam.password_policy.ExpirePasswords">{{items.ExpirePasswords}}</span></div>
      {{#if items.MaxPasswordAge}}
        <div class="list-group-item-text item-margin">Password expiration period (in days): <span id="iam.password_policy.MaxPasswordAge">{{items.MaxPasswordAge}}</span></div>
      {{/if}}
      <div class="list-group-item-text item-margin">Prevent password reuse: <span id="iam.password_policy.PasswordReusePrevention">{{items.PasswordReusePrevention}}</span></div>
      {{#if items.PreviousPasswordPrevented}}
        <div class="list-group-item-text item-margin">Number of passwords to remember: <span id="iam.password_policy.PreviousPasswordPrevented">{{items.PreviousPasswordPrevented}}</span></div>
        <div class="list-group-item-text item-margin">Allow users to change their own password: <span id="iam.password_policy.AllowUsersToChangePassword">{{items.AllowUsersToChangePassword}}</span></div>
        <div class="list-group-item-text item-margin">Allow users to set a new password after their password has expired: <span id="iam.password_policy.HardExpiry">{{items.HardExpiry}}</span></div>
      {{/if}}
    </div>
  </div></div>
  </script>

