
    <!-- IP grant -->
    <script id="ip_grants.partial" type="text/x-handlebars-template">
      <ul>
        {{#each items}}
          <span id="ec2.regions.{{../region}}.vpcs.{{../vpc}}.security_groups.{{../sg_id}}.rules.{{../direction}}.protocols.{{../protocol}}.ports.{{../ports}}.cidrs.{{@key}}.CIDR">
            <span class="ec2_attack_surface_item">
              <li class="list-group-item-text">{{CIDR}} {{#if CIDRName}}({{CIDRName}}){{/if}}</li>
            </span>
          </span>
        {{/each}}
      </ul>
    </script>
    <script>
        Handlebars.registerPartial("ip_grants", $("#ip_grants\\.partial").html());
    </script>

