.item-margin {
    margin-left: 25px;
}
.no-margin {
    margin-left: -25px !important;
}

.finding-hidden {
    display: none;
}
.finding-danger {
    color:  red !important;
    display: inline !important;
}
.finding-title-danger {
    background: red!important;
}
.finding-warning {
    color: orange !important;
    display: inline !important;
}
.finding-title-warning {
    background: orange !important;
}
.finding-good {
    color: green !important;
    display: inline !important;
}
.finding-title-good {
    background: green !important;
}
.finding-title-unknown {
    background: #eee !important;
}

ul.no-bullet {
    list-style-type: none;
}
.list-sub-element {
    border: 0 !important;
    padding-left: 25px;
}

.active-dropdown {
    color: #428bca;
}

.overlay-bg {
    position: fixed;
    top: 0;
    left: 0;
    width: 100%;
    height: 100%;
    background: black;
    z-index: 1337;
    opacity: 0.5;
    display: none;
}
.overlay {
    position: fixed;
    top: 40%;
    left: 40%;
    max-height: 80%;
    background-color: white;
    z-index: 7331;
    overflow: auto;
    margin-left: -200px;
    margin-top: -200px;
    display: none;
    border-radius: 5px;
}

.plain-link a:link {
    color: black !important;
    text-decoration: none !important;
}
.plain-link a:visited {
    color: black !important;
    text-decoration: none !important;
}
.plain-link a:hover {
    color: black !important;
    text-decoration: none !important;
}
.plain-link a:active {
    color: black !important;
    text-decoration: none !important;
}
.disabled-link a:link{
    pointer-events: none;
    cursor: default;
}
.disabled-link a:visited{
    pointer-events: none;
    cursor: default;
}
.disabled-link a:hover{
    pointer-events: none;
    cursor: default;
}
.disabled-link a:active{
    pointer-events: none;
    cursor: default;
}

.active a{
    text-decoration: none !important;
    color: black !important;
}

.dropdown-submenu {
    position: relative;
}

.dropdown-submenu>.dropdown-menu {
    top: 0;
    left: 100%;
    margin-top: -6px;
    margin-left: -1px;
    -webkit-border-radius: 0 6px 6px 6px;
    -moz-border-radius: 0 6px 6px;
    border-radius: 0 6px 6px 6px;
}

.dropdown-submenu:hover>.dropdown-menu {
    display: block;
}

.dropdown-submenu>a:after {
    display: block;
    content: " ";
    float: right;
    width: 0;
    height: 0;
    border-color: transparent;
    border-style: solid;
    border-width: 5px 0 5px 5px;
    border-left-color: #ccc;
    margin-top: 5px;
    margin-right: -10px;
}

.dropdown-submenu:hover>a:after {
    border-left-color: #fff;
}

.dropdown-submenu.pull-left {
    float: none;
}

.dropdown-submenu.pull-left>.dropdown-menu {
    left: -100%;
    margin-left: 10px;
    -webkit-border-radius: 6px 0 6px 6px;
    -moz-border-radius: 6px 0 6px 6px;
    border-radius: 6px 0 6px 6px;
}

.rationale-overlay {
    z-index: 2147483647;
    display: block;
    position: fixed;
    width: 20%;
    display: none;
}