
    <!-- EC2 ELB partial -->
    <script id="services.ec2.regions.id.vpcs.id.elbs.partial" type="text/x-handlebars-template">
        <div class="list-group-item active">
          <h4 class="list-group-item-heading">{{name}}</h4>
        </div>
        <div class="list-group-item">
          <h4>Network</h4>
          <ul>
            <li class="list-group-item-text">VPC: {{get_value_at 'services.ec2.regions' region 'vpcs' vpc 'name'}} ({{vpc}})</li>
            <li class="list-group-item-text">DNS: {{DNSName}}</li>
            <li class="list-group-item-text">Availability zones:</li>
            <ul>
              {{#each AvailabilityZones}}
                <li class="list-group-item-text">{{this}}</li>
              {{/each}}
            </ul>
          </ul>
        </div>
        <div class="list-group-item">
          <h4>Listeners</h4>
          <ul>
          {{#each listeners}}
            <li class="list-group-item-text">
              {{LoadBalancerPort}} ({{Protocol}}) <i class="glyphicon glyphicon-arrow-right"></i> {{InstancePort}} ({{InstanceProtocol}})
              {{#if SslCertificateId}} :
                {{#each policy_names}}
                  <span id="services.ec2.regions.vpcs.elbs-old-ssl-policy-{{../../../name}}-{{this}}">{{this}}</span>
                {{/each}}
              {{/if}}
            </li>
          {{/each}}
          </ul>
        </div>
        <div class="list-group-item" style="padding-bottom: 0 !important;">
          <div class="accordion">
            <h4 class="list-group-item-heading accordion-heading">Security groups
              <a class="accordion-toggle" data-toggle="collapse" href="#services\.ec2\.regions\.{{region}}\.vpcs\.{{vpc}}\.elbs\.{{@key}}\.security_groups"><span class="badge pull-right btn-info">{{security_groups.length}}</span></a>
            </h4>
            <div id="services.ec2.regions.{{region}}.vpcs.{{vpc}}.elbs.{{@key}}.security_groups" class="accordion-body collapse">
              <div class="accordion-inner">
                <ul class="no-bullet">
                  {{#each security_groups}}
                    <li><a href="javascript:showObject('services.ec2.regions.{{../region}}.vpcs.{{../vpc}}.security_groups.{{GroupId}}')">{{GroupId}}</a></li>
                  {{/each}}
                </ul>
              </div>
            </div>
          </div>
        </div>
        <div class="list-group-item">
          <h4>Destination</h4>
          <ul>
            {{> services.ec2.regions.vpcs.elbs.linked_resources region = region vpc = vpc resources = instances resource_type = 'instances'}}
            {{> services.ec2.regions.vpcs.elbs.linked_resources region = region vpc = vpc resources = Subnets resource_type = 'subnets'}}
        </div>
    </script>
    <script>
      Handlebars.registerPartial("services.ec2.regions.id.vpcs.id.elbs", $("#services\\.ec2\\.regions\\.id\\.vpcs\\.id\\.elbs\\.partial").html());
    </script>

